pub fn validate_annotation_markers(
document: &McdDocument,
annotations: &IndexMap<String, AnnotationMetadata>,
) -> Result<()>Expand description
Validate all Markdown annotation markers against declared annotation metadata.
pub fn validate_annotation_markers(
document: &McdDocument,
annotations: &IndexMap<String, AnnotationMetadata>,
) -> Result<()>Validate all Markdown annotation markers against declared annotation metadata.