Module assets

Module assets 

Package asset validation helpers.

Functions

asset_path_allowed
Return true when an asset path is allowed by the default asset directory or manifest entries.
detect_media_type
Detect media type from the asset path.
sha256_hash
Compute a stable sha256:<hex> hash string.
validate_image_asset
Validate asset path, existence, media type, hash, and SVG safety.