McdPackage

Struct McdPackage 

pub struct McdPackage { /* private fields */ }
An opened MCD package with validated internal paths.

Implementations

Source

impl McdPackage

pub fn open_path(path: impl AsRef<Path>) -> Result<Self>

Open a package from a filesystem path.

pub fn from_bytes(bytes: &[u8]) -> Result<Self>

Open a package from in-memory bytes.

pub fn from_markdown(markdown: &str) -> Self

Build a minimal package from a standalone Markdown document.

pub fn from_reader<R>(reader: R) -> Result<Self>
where R: Read + Seek,

Open a package from any readable and seekable ZIP stream.

pub fn entry_paths(&self) -> Vec<&str>

Return sorted package entry paths.

pub fn contains(&self, path: &str) -> bool

Check if the package has a path.

pub fn read(&self, path: &str) -> Result<&[u8]>

Read package bytes for an internal path.

pub fn read_to_string(&self, path: &str) -> Result<String>

Read a package entry as UTF-8 text.

pub fn manifest(&self) -> Result<Manifest>

Parse the root manifest.

pub fn search( &self, query: &str, options: SearchOptions, ) -> Result<Vec<SearchHit>>

Search package content and metadata with the built-in BM25 index.

pub fn validate_mimetype(&self) -> Result<()>

Validate the root mimetype entry.