Package asset validation helpers.
Functions
- asset_
path_ allowed - Return true when an asset path is allowed by the default asset directory or manifest entries.
- detect_
media_ type - Detect media type from the asset path.
- sha256_
hash - Compute a stable
sha256:<hex>hash string. - validate_
image_ asset - Validate asset path, existence, media type, hash, and SVG safety.