CSV table loading and typed value coercion.
Structs
Enums
- Typed
Value - A typed table cell value.
Functions
- coerce_
cell - Coerce one CSV cell into its schema type.
- load_
manifest_ tables - Load all manifest-declared tables in manifest order.
- row_key
- Return a stable typed key for a row, or
Noneif any key part is null. - typed_
key_ part - Return a stable typed key part for relational comparisons.